summaryrefslogtreecommitdiff
path: root/src/mongo/executor/network_connection_hook.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/executor/network_connection_hook.h')
-rw-r--r--src/mongo/executor/network_connection_hook.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/executor/network_connection_hook.h b/src/mongo/executor/network_connection_hook.h
index 04de5571cb6..8510344c85a 100644
--- a/src/mongo/executor/network_connection_hook.h
+++ b/src/mongo/executor/network_connection_hook.h
@@ -54,16 +54,16 @@ public:
virtual ~NetworkConnectionHook() = default;
/**
* Optionally augments the isMaster request sent while initializing the wire protocol.
*
* By default this will just return the cmdObj passed in unaltered.
*/
- virtual BSONObj augmentIsMasterRequest(const HostAndPort& remoteHost, BSONObj cmdObj) {
+ virtual BSONObj augmentHelloRequest(const HostAndPort& remoteHost, BSONObj cmdObj) {
return cmdObj;
}
/**
* Runs optional validation logic on an isMaster reply from a remote host. If a non-OK
* Status is returned, it will be propagated up to the completion handler for the command
* that initiated the request that caused this connection to be created. This will
* be called once for each connection that is created, even if a remote host with the
@@ -77,8 +77,8 @@ public:
* std::terminate.
*/
virtual Status validateHost(const HostAndPort& remoteHost,
- const BSONObj& isMasterRequest,
- const RemoteCommandResponse& isMasterReply) = 0;
+ const BSONObj& helloRequest,
+ const RemoteCommandResponse& helloReply) = 0;
/**
* Generates a command to run on the remote host immediately after connecting to it.
@@ -54,16 +54,16 @@ public:
virtual ~NetworkConnectionHook() = default;
/**
- * Optionally augments the isMaster request sent while initializing the wire protocol.
+ * Optionally augments the "hello" request sent while initializing the wire protocol.
*
* By default this will just return the cmdObj passed in unaltered.
@@ -54,16 +54,16 @@ public:
}
/**
- * Runs optional validation logic on an isMaster reply from a remote host. If a non-OK
+ * Runs optional validation logic on an "hello" reply from a remote host. If a non-OK
* Status is returned, it will be propagated up to the completion handler for the command
* that initiated the request that caused this connection to be created. This will